<?php

// Class for the orders

class class_MRWP_order {


// Get the Mondial Relay orders
    public static function get_orders($limit_start, $pagination) {
        global $wpdb;
        $prefixe = $wpdb->prefix;

        $orders = $wpdb->get_results( "SELECT ID, DATE_FORMAT(post_date, '%d/%m/%Y') as datefr, post_status FROM " . $prefixe . "posts WHERE post_type ='shop_order' ORDER BY ID DESC LIMIT " . $limit_start . "," . $pagination);
        return $orders;
    }

// Get SQL checkout attributes
    public static function get_params_checkout() {
        $params = array(
            'mondialrelay_code_client',
            'mondialrelay_id_livraison',
            'mondialrelay_ids_livraison',
            'mondialrelay_nb_results',
        );
        return $params;
    }

// Get the Mondial Relay account attributes
    public static function get_params_compte() {
        global $wpdb;
        $prefixe = $wpdb->prefix;

        $params_compte = array(
            'mondialrelay_code_client' => '',
            'mondialrelay_code_marque' => '',
            'mondialrelay_cle_privee' => ''
        );
        foreach($params_compte as $key => $param) {
            $params_compte[$key] = get_option($key, 1);
        }
        return $params_compte;
    }

// Get the Mondial Relay expediteur attributes
    public static function get_params_expediteur() {
        global $wpdb;
        $prefixe = $wpdb->prefix;

        $params_expediteur = array(
            'mondialrelay_vendeur_adresse1' => '',
            'mondialrelay_vendeur_adresse2' => '',
            'mondialrelay_vendeur_adresse3' => '',
            'mondialrelay_vendeur_adresse4' => '',
            'mondialrelay_vendeur_cp' => '',
            'mondialrelay_vendeur_ville' => '',
            'mondialrelay_vendeur_pays' => '',
            'mondialrelay_vendeur_tel' => '',
            'mondialrelay_vendeur_tel2' => '',
            'mondialrelay_vendeur_email' => ''
        );
        foreach($params_expediteur as $key => $param) {
            $params_expediteur[$key] = get_option($key, 1);
        }
        $params_expediteur['mondialrelay_vendeur_langage'] = class_MRWP_helpers::get_langue($params_expediteur['mondialrelay_vendeur_pays']);
        $params_expediteur['mondialrelay_vendeur_adresse1'] = remove_accents($params_expediteur['mondialrelay_vendeur_adresse1']);
        $params_expediteur['mondialrelay_vendeur_adresse2'] = remove_accents($params_expediteur['mondialrelay_vendeur_adresse2']);
        $params_expediteur['mondialrelay_vendeur_adresse3'] = remove_accents($params_expediteur['mondialrelay_vendeur_adresse3']);
        $params_expediteur['mondialrelay_vendeur_adresse4'] = remove_accents($params_expediteur['mondialrelay_vendeur_adresse4']);
        $params_expediteur['mondialrelay_vendeur_ville'] = remove_accents($params_expediteur['mondialrelay_vendeur_ville']);
        return $params_expediteur;
    }

// Get the Mondial Relay destinataire attribute
    public static function get_params_destinataire($order_id) {
        global $wpdb;
        $prefixe = $wpdb->prefix;

        $params_destinataire = array(
            '_shipping_last_name' => '',
            '_shipping_first_name' => '',
            '_shipping_company' => '',
            '_billing_email' => '',
            '_billing_phone' => '',
            '_shipping_address_1' => '',
            '_shipping_address_2' => '',
            '_shipping_city' => '',
            '_shipping_postcode' => '',
            '_shipping_country' => ''
        );
        foreach($params_destinataire as $key => $param) {
            $params_destinataire[$key] = $wpdb->get_var( "SELECT meta_value FROM " . $prefixe . "postmeta WHERE post_id = '" . $order_id . "' AND meta_key = '$key'" );
        }
        $params_destinataire['_shipping_langage'] = class_MRWP_helpers::get_langue($params_destinataire['_shipping_country']);
        $params_destinataire['_shipping_full_name'] = $params_destinataire['_shipping_last_name'] . ' ' . $params_destinataire['_shipping_first_name'];
        $params_destinataire['_shipping_full_name'] = remove_accents($params_destinataire['_shipping_full_name']);

        $billing_country = get_post_meta( $order_id, '_billing_country', true );

        $params_destinataire['_billing_phone'] = class_MRWP_helpers::phone_validation($billing_country,$params_destinataire['_billing_phone']);
        return $params_destinataire;
    }

// Get the Mondial Relay order attributes
    public static function get_params_commande() {
        global $wpdb;
        $prefixe = $wpdb->prefix;

        $params_commande = array(
            'ModeCol' => class_MRWP_main::MODE_COL,
            'Poids' => '',
            'NbColis' => class_MRWP_main::NB_COLIS,
            'CRT_Valeur' => class_MRWP_main::CRT_VALEUR,
            'NDossier' => '',
            'NClient' => '',
            'Longueur' => '',
            'Taille' => '',
            'CRT_Devise' => '',
            'Exp_Valeur' => '',
            'Exp_Devise' => '',
            'TAvisage' => '',
            'TReprise' => '',
            'Montage' => '',
            'TRDV' => '',
            'Instructions' => '',
        );
        foreach($params_commande as $key => $param) {
            if (isset($_POST[$key]))
                $params_commande[$key] = $_POST[$key];
        }
        return $params_commande;
    }

// Get the Mondial Relay delivery attributes
    public static function get_params_livraison() {
        $params_livraison = array(
            'liv_rel_pays_mondial_relay' => '',
            'liv_rel_mondial_relay' => ''
        );
        return $params_livraison;
    }

// Get the Mondial Relay collect attributes
    public static function get_params_collecte() {
        $params_collecte = array(
            'col_rel_pays_mondial_relay' => '',
            'col_rel_mondial_relay' => ''
        );
        return $params_collecte;
    }

// Get SQL expedition attributes
    public static function get_expedition_champs($expedition, $nb_colis) {
        $champs = array(
            'ExpeditionNum' => $expedition->ExpeditionNum,
            'TRI_AgenceCode' => $expedition->TRI_AgenceCode,
            'TRI_Groupe' => $expedition->TRI_Groupe,
            'TRI_Navette' => $expedition->TRI_Navette,
            'TRI_Agence' => $expedition->TRI_Agence,
            'TRI_TourneeCode' => $expedition->TRI_TourneeCode,
            'TRI_LivraisonMode' => $expedition->TRI_LivraisonMode,
            'ExpeditionStatus' => '800',
            'ExpeditionStatusDate' => time(),
        );
        // Add the bar code
        if ($nb_colis == 1) {
            $champs['CodesBarres'] = $expedition->CodesBarres->string;
        }
        elseif ($nb_colis > 1) {
            $i = 0;
            while ($i < $nb_colis) {
                $champs['CodesBarres_' . $i] = $expedition->CodesBarres->string[$i];
                $i++;
            }
        }
        return $champs;
    }

// Get SQL emails attributes
    public static function get_params_emails($order_id) {
        $email['send'] = get_option( 'mondialrelay_email_send', 0 );
        $email['multi_lang'] = get_option( 'mondialrelay_email_multi_lang', 0 );

        // Si l'option multilingue est activée
        if ($email['multi_lang'] == 1) {
            // on récupère la langue de la commande
            $email['lang'] = class_MRWP_db::get_meta_champ($order_id, 'Mondial Relay User Lang');
            // on récupère uniquement la langue sans la localisation
            $email['lang'] = substr($email['lang'], 0, 2);

            // En fonction de la langue, on récupère le bon message
            if( $email['lang'] == 'fr' ) {
                $email['message'] = get_option( 'mondialrelay_email_expedition_message');
                $email['sujet'] = get_option( 'mondialrelay_email_expedition_sujet');
            } elseif( $email['lang'] == 'es' ) {
                $email['message'] = get_option( 'mondialrelay_email_expedition_message_es');
                $email['sujet'] = get_option( 'mondialrelay_email_expedition_sujet_es');
            } elseif( $email['lang'] == 'nl' ) {
                $email['message'] = get_option( 'mondialrelay_email_expedition_message_nl');
                $email['sujet'] = get_option( 'mondialrelay_email_expedition_sujet_nl');
            } else {
                $email['message'] = get_option( 'mondialrelay_email_expedition_message_en');
                $email['sujet'] = get_option( 'mondialrelay_email_expedition_sujet_en');
            }

        // Si l'option multilingue est désactivée, on récupère le mail unique
        } else {
            $email['message'] = get_option( 'mondialrelay_email_expedition_message');
            $email['sujet'] = get_option( 'mondialrelay_email_expedition_sujet');
        }

        // on parse les shortcodes
        $email['message'] = class_MRWP_Helpers::parse_shortcodes($order_id, $email['message']);
        $email['sujet'] = class_MRWP_Helpers::parse_shortcodes($order_id, $email['sujet']);
        return $email;
    }

}